@@ -11,9 +11,9 @@ require("nonebot_plugin_waiter")
 from . import matchers
 from .config import Config
 
-__version__ = "1.0.8"
+__version__ = "1.0.9"
 __plugin_meta__ = PluginMetadata(
-    name="exe_code",
+    name="nonebot-plugin-exe-code",
     description="在对话中执行 Python 代码",
     usage="code {Your code here...}",
     type="application",
