@@ -15,8 +15,8 @@ from ..context import Context
 
 def _AllowExeCode() -> Permission:
 
-    def check_console(bot: Bot) -> bool:  # pyright: ignore[reportRedeclaration]
-        return True  # pragma: no cover
+    def check_console(bot: Bot) -> bool:  # pragma: no cover
+        return True
 
     with contextlib.suppress(ImportError):
         from nonebot.adapters.console import Bot as ConsoleBot
@@ -27,7 +27,7 @@ def _AllowExeCode() -> Permission:
     async def check(bot: Bot, session: EventSession) -> bool:
         # ConsoleBot 仅有标准输入, 跳过检查
         if check_console(bot):
-            return True  # pragma: no cover
+            return True
 
         # 对于 superuser 和 配置允许的用户, 在任意对话均可触发
         if (session.id1 or "") in config.user:
@@ -73,18 +73,21 @@ def _ExtractCode():
 
 
 def _EventImage():
-
-    async def event_image(msg: UniMsg) -> Image:
+    async def event_image(msg: UniMessage, _in_reply: bool = False) -> Image:
         if msg.has(Image):
             return msg[Image, 0]
-        elif msg.has(Reply):
+        elif msg.has(Reply) and not _in_reply:
             reply = msg[Reply, 0].msg
             if isinstance(reply, Message):
                 msg = await UniMessage.generate(message=reply)
-                return await event_image(msg)
-        Matcher.skip()  # pragma: no cover
+                return await event_image(msg, True)
 
-    return Depends(event_image)
+        Matcher.skip()
+
+    async def dependency(msg: UniMsg) -> Image:
+        return await event_image(msg)
+
+    return Depends(dependency)
 
 
 def _EventReply():
@@ -92,7 +95,7 @@ def _EventReply():
     async def event_reply(event: Event, bot: Bot) -> Reply:
         if reply := await reply_fetch(event, bot):
             return reply
-        Matcher.skip()  # pragma: no cover
+        Matcher.skip()
 
     return Depends(event_reply)
 
@@ -100,10 +103,10 @@ def _EventReply():
 def _EventReplyMessage():
 
     async def event_reply_message(event: Event, reply: EventReply) -> Message:
-        if not (msg := reply.msg):  # pragma: no cover
+        if not (msg := reply.msg):
             Matcher.skip()
 
-        if not isinstance(msg, Message):  # pragma: no cover
+        if not isinstance(msg, Message):
             msg = type(event.get_message())(msg)
 
         return msg
